from setuptools import setup

setup(name='punj-distributions',
      version='0.2',
      description='Gaussian & Binomial distributions',
      packages=['punj-distributions'],
      zip_safe=False)
